@@ -189,7 +189,7 @@ arma::mat compute_pi(
     if (val < minPi) {
       val = minPi;
     }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
   }
@@ -220,7 +220,7 @@ arma::mat compute_quadratic_term(
     if (val < minPi) {
       val = minPi;
     }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
   }
@@ -234,7 +234,7 @@ arma::mat compute_quadratic_term(
     if (val < minPi) {
       val = minPi;
     }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
   }
@@ -313,7 +313,7 @@ arma::mat  compute_quadratic_term_directed(
     if (val < minPi) {
       val = minPi;
     }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
   }
@@ -327,7 +327,7 @@ arma::mat  compute_quadratic_term_directed(
     if (val < minPi) {
       val = minPi;
     }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
   }
@@ -546,7 +546,7 @@ arma::mat compute_pi_d1x0(
     if (val < minPi) {
       val = minPi;
       }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
     }
@@ -580,7 +580,7 @@ arma::mat compute_quadratic_term_with_features(
     if (val < minPi) {
       val = minPi;
     }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
   }
@@ -666,7 +666,7 @@ arma::mat compute_quadratic_term_with_features(
       if (val < minPi) {
         val = minPi;
       }
-      if (!arma::is_finite(val)) {
+      if (!std::isfinite(val)) {
         val = minPi;
       } 
     }
@@ -683,7 +683,7 @@ arma::mat compute_quadratic_term_with_features(
       if (val < minPi) {
         val = minPi;
       }
-      if (!arma::is_finite(val)) {
+      if (!std::isfinite(val)) {
         val = minPi;
       } 
     }
@@ -771,7 +771,7 @@ arma::mat compute_quadratic_term_with_features_directed(
     if (val < minPi) {
       val = minPi;
     }
-    if (!arma::is_finite(val)) {
+    if (!std::isfinite(val)) {
       val = minPi;
     } 
   }
@@ -860,7 +860,7 @@ arma::mat compute_quadratic_term_with_features_directed(
       if (val < minPi) {
         val = minPi;
       }
-      if (!arma::is_finite(val)) {
+      if (!std::isfinite(val)) {
         val = minPi;
       } 
     }
@@ -877,7 +877,7 @@ arma::mat compute_quadratic_term_with_features_directed(
       if (val < minPi) {
         val = minPi;
       }
-      if (!arma::is_finite(val)) {
+      if (!std::isfinite(val)) {
         val = minPi;
       } 
     }
